@@ -28,7 +28,7 @@ import os.path
 import mock
 
 from pyongc.scripts import ongc
-from pyongc.ongc import __version__ as version
+from pyongc import __version__ as version
 
 
 def test_view():
@@ -44,11 +44,16 @@ def test_view_details():
     assert result.exit_code == 0
     assert result.output == (
         "+-----------------------------------------------------------------------------+\n"
-        "| Id: 5616      Name: NGC0001           Type: Galaxy                          |\n"
+        "| Id: 5596      Name: NGC0001           Type: Galaxy                          |\n"
         "| R.A.: 00:07:15.84      Dec.: +27:42:29.1      Constellation: Peg            |\n"
         "+-----------------------------------------------------------------------------+\n"
         "| Major axis: 1.57'      Minor axis: 1.07'      Position angle: 112°          |\n"
-        "| B-mag: 13.4    V-mag: N/A     J-mag: 10.78   H-mag: 10.02   K-mag: 9.76     |\n"
+        "| B-mag: 13.69   V-mag: 12.93   J-mag: 10.78   H-mag: 10.02   K-mag: 9.76     |\n"
+        "|                                                                             |\n"
+        "| Parallax: N/A          Radial velocity: 4536km/s      Redshift: 0.015245    |\n"
+        "|                                                                             |\n"
+        "| Proper apparent motion in RA: N/A                                           |\n"
+        "| Proper apparent motion in Dec: N/A                                          |\n"
         "|                                                                             |\n"
         "| Surface brightness: 23.13     Hubble classification: Sb                     |\n"
         "+-----------------------------------------------------------------------------+\n"
@@ -84,7 +89,7 @@ def test_stats_database_error():
     runner = CliRunner()
     result = runner.invoke(ongc.stats)
     assert result.exit_code == 0
-    assert 'ERROR: There was a problem accessing database file at badpath\n'in result.output
+    assert 'ERROR: There was a problem accessing database file at badpath\n' in result.output
 
 
 def test_neighbors():
@@ -222,7 +227,7 @@ def test_search_with_maxsize_filter():
     result = runner.invoke(ongc.search, ['--maxsize=0.5'])
     assert result.exit_code == 0
     assert 'WARNING: the result list is long. Do you want to see it via a pager?' in result.output
-    assert result.output.endswith('M040, Double star in UMa\n')
+    assert result.output.endswith('NGC5457, Galaxy in UMa\n')
 
 
 def test_search_with_uptobmag_filter():
@@ -307,6 +312,35 @@ def test_search_to_file():
         result = runner.invoke(ongc.search, ['--constellation=aql', '--out_file=test.txt'])
         assert result.exit_code == 0
         assert os.path.isfile('test.txt')
+        with open('test.txt') as f:
+            assert '\nNGC6915\n' in f.read()
+
+
+def test_search_to_custom_file():
+    runner = CliRunner()
+    with runner.isolated_filesystem():
+        result = runner.invoke(ongc.search, [
+            '--include_fields=name,type,cstarnames',
+            '--constellation=her',
+            '--out_file=test.csv',
+        ])
+        assert result.exit_code == 0
+        assert os.path.isfile('test.csv')
+        with open('test.csv') as f:
+            assert '\nIC4593;Planetary Nebula;BD +12 2966,HD 145649\n' in f.read()
+
+
+def test_search_to_custom_file_invalid_field():
+    runner = CliRunner()
+    with runner.isolated_filesystem():
+        result = runner.invoke(ongc.search, [
+            '--constellation=her',
+            '--out_file=test.csv',
+            '--include_fields=test'
+        ])
+        assert result.exit_code == 0
+        assert result.output == "ERROR: 'Dso' object has no attribute '_test'\n"
+        assert not os.path.isfile('test.csv')
 
 
 def test_search_no_results():
@@ -329,7 +363,7 @@ def test_search_database_error():
     runner = CliRunner()
     result = runner.invoke(ongc.search)
     assert result.exit_code == 0
-    assert 'ERROR: There was a problem accessing database file at badpath\n'in result.output
+    assert 'ERROR: There was a problem accessing database file at badpath\n' in result.output
 
 
 def test_nearby():
